@@ -7,11 +7,11 @@ describe('Circle', function () {
 			circle = L.circle([50, 30], 200);
 		});
 
-		it('should return correct bounds', function () {
+		it('returns bounds', function () {
 			var bounds = circle.getBounds();
 
-			expect(bounds.getSouthWest().equals([49.998203369, 29.997204939])).toBeTruthy();
-			expect(bounds.getNorthEast().equals([50.001796631, 30.002795061])).toBeTruthy();
+			expect(bounds.getSouthWest().equals([49.998203369, 29.997204939])).to.be.ok();
+			expect(bounds.getNorthEast().equals([50.001796631, 30.002795061])).to.be.ok();
 		});
 	});
 });
